import type { AccountInfo } from '@azure/msal-browser';
import type { App } from 'vue';
import type { AuthenticationResult } from '@azure/msal-browser';
import type { AuthError } from '@azure/msal-browser';
import { ComputedRef } from 'vue';
import type { Configuration } from '@azure/msal-browser';
import type { EndSessionPopupRequest } from '@azure/msal-browser';
import type { EndSessionRequest } from '@azure/msal-browser';
import { InteractionStatus } from '@azure/msal-browser';
import { InteractionType } from '@azure/msal-browser';
import type { Logger } from '@azure/msal-browser';
import type { Plugin as Plugin_2 } from 'vue';
import type { PopupRequest } from '@azure/msal-browser';
import { PublicClientApplication } from '@azure/msal-browser';
import type { RedirectRequest } from '@azure/msal-browser';
import { Ref } from 'vue';
import type { Router } from 'vue-router';
import type { SilentRequest } from '@azure/msal-browser';

/**
 * Function createMsal
 * Creates a Msal plugin instance to be used by the application
 * @public
 */
export declare function createMsal(msalOptions: MsalCreateOptions): MsalPlugin;

/**
 * Type: MsalAccount
 * Returned by useMsalAccount
 * @public
 */
export declare type MsalAccount = {
    account: Ref<AccountInfo | null>;
    name: ComputedRef<string>;
    username: ComputedRef<string>;
    switchAccount: (newAccount: AccountInfo) => Promise<void>;
};

/**
 * Type: MsalAuthResult
 * Returned by useMsalAuthentication
 * @public
 */
export declare type MsalAuthResult = {
    acquireToken: (requestOverride?: PopupRequest | RedirectRequest | SilentRequest) => Promise<void>;
    result: Ref<AuthenticationResult | null>;
    error: Ref<AuthError | null>;
};

/**
 * Type: MsalContext
 * Returned by useMsal()
 * @public
 */
export declare type MsalContext = {
    instance: PublicClientApplication;
    inProgress: Ref<InteractionStatus>;
    account: Ref<AccountInfo | null>;
    accounts: Ref<AccountInfo[]>;
    ops: {
        login: (loginRequestOverride?: PopupRequest | RedirectRequest | SilentRequest) => void;
        logout: (logoutRequestOverrides?: EndSessionPopupRequest | EndSessionRequest) => void;
    };
};

/**
 * Type: MsalCreateOptions
 * @public
 */
export declare type MsalCreateOptions = {
    configuration: Configuration;
    interactionType?: InteractionType;
    loginRequest?: PopupRequest | RedirectRequest | SilentRequest;
};

/**
 * Class MsalPlugin
 * @public
 */
export declare class MsalPlugin implements Pick<Plugin_2<MsalPluginOptions>, keyof Plugin_2<MsalPluginOptions>> {
    instance: PublicClientApplication;
    options: {
        interactionType: InteractionType;
        loginRequest: PopupRequest | RedirectRequest | SilentRequest;
    };
    private _state;
    private _logger;
    private _eventCallbacks;
    private _initResolver;
    waitInitPromise: Promise<void>;
    constructor(msalOptions: MsalCreateOptions);
    getLogger(): Logger;
    getCurrentInteractionStaus(): InteractionStatus;
    install(app: App, options: MsalPluginOptions): Promise<void>;
    private updateStatusByMessage;
    private resetInProgress;
    private updateAccounts;
    private setNewActiveAccount;
    private resetAccount;
    private waitInit;
    private doneInit;
}

/**
 * Type: MsalPluginOptions
 * @public
 */
export declare type MsalPluginOptions = {
    router?: Router;
};

/** @public */
export declare const pkgBuildDate = "__pkgBuildDate__";

/** @public */
export declare const pkgName = "__pkgName__";

/** @public */
export declare const pkgVersion = "__pkgVersion__";

/**
 * Function useAccount
 * @returns
 * @public
 */
export declare function useAccount(): {
    account: Ref<AccountInfo | null>;
    name: ComputedRef<string>;
    username: ComputedRef<string>;
    switchAccount: (newAccount: AccountInfo) => Promise<void>;
};

/**
 * Function useIsAuthenticated
 * @returns
 * @public
 */
export declare function useIsAuthenticated(): Ref<boolean>;

/**
 * Function useMsal
 * @returns
 * @public
 */
export declare function useMsal(): MsalContext;

/**
 * Function useMsalAuthentication
 * @returns
 * @public
 */
export declare function useMsalAuthentication(): MsalAuthResult;

export { }
